import { tryAtIntervals, createExponentialBackoffStrategy } from "../../../internal/async/interval-retrier.js";
import { API } from "./api.gen.js";
import { SERVER_INSTALL_TRANSIENT_STATUSES } from "./content.gen.js";
class BaremetalV1UtilsAPI extends API {
  /**
   * Waits for {@link ServerInstall} to be in a final state.
   *
   * @param request - The request {@link GetServerRequest}
   * @param options - The waiting options
   * @returns A Promise of ServerInstall
   */
  waitForServerInstall = (request, options) => tryAtIntervals(
    async () => {
      const value = await this.getServer(request).then((server) => {
        if (!server.install) {
          throw new Error(
            `Server creation has not begun for server ${request.serverId}`
          );
        }
        return server.install;
      });
      return {
        done: !SERVER_INSTALL_TRANSIENT_STATUSES.includes(value.status),
        value
      };
    },
    createExponentialBackoffStrategy(
      options?.minDelay ?? 1,
      options?.maxDelay ?? 30
    ),
    options?.timeout
  );
}
export {
  BaremetalV1UtilsAPI
};
