"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const json = require("../../../helpers/json.cjs");
const marshalling = require("../../../helpers/marshalling.cjs");
const unmarshalCategory = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Category' failed as data isn't a dictionary.`
    );
  }
  return {
    description: data.description,
    id: data.id,
    name: data.name
  };
};
const unmarshalImage = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Image' failed as data isn't a dictionary.`
    );
  }
  return {
    categories: data.categories,
    createdAt: marshalling.unmarshalDate(data.created_at),
    description: data.description,
    id: data.id,
    label: data.label,
    logo: data.logo,
    name: data.name,
    updatedAt: marshalling.unmarshalDate(data.updated_at),
    validUntil: marshalling.unmarshalDate(data.valid_until)
  };
};
const unmarshalLocalImage = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'LocalImage' failed as data isn't a dictionary.`
    );
  }
  return {
    arch: data.arch,
    compatibleCommercialTypes: data.compatible_commercial_types,
    id: data.id,
    label: data.label,
    type: data.type,
    zone: data.zone
  };
};
const unmarshalVersion = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Version' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    id: data.id,
    name: data.name,
    publishedAt: marshalling.unmarshalDate(data.published_at),
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalListCategoriesResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListCategoriesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    categories: marshalling.unmarshalArrayOfObject(data.categories, unmarshalCategory),
    totalCount: data.total_count
  };
};
const unmarshalListImagesResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListImagesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    images: marshalling.unmarshalArrayOfObject(data.images, unmarshalImage),
    totalCount: data.total_count
  };
};
const unmarshalListLocalImagesResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListLocalImagesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    localImages: marshalling.unmarshalArrayOfObject(data.local_images, unmarshalLocalImage),
    totalCount: data.total_count
  };
};
const unmarshalListVersionsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListVersionsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    totalCount: data.total_count,
    versions: marshalling.unmarshalArrayOfObject(data.versions, unmarshalVersion)
  };
};
exports.unmarshalCategory = unmarshalCategory;
exports.unmarshalImage = unmarshalImage;
exports.unmarshalListCategoriesResponse = unmarshalListCategoriesResponse;
exports.unmarshalListImagesResponse = unmarshalListImagesResponse;
exports.unmarshalListLocalImagesResponse = unmarshalListLocalImagesResponse;
exports.unmarshalListVersionsResponse = unmarshalListVersionsResponse;
exports.unmarshalLocalImage = unmarshalLocalImage;
exports.unmarshalVersion = unmarshalVersion;
